#!/usr/bin/env sh

# Keep only desired lines, output to lines.dat
grep icmp_req bad_name.bones > lines.dat
# Parse out values from each line of lines.dat to parsed.dat
sed 's/64 bytes from \([A-Za-z0-9.-]*\) ([0-9.]*): icmp_req=\([0-9]*\) ttl=[0-9]* time=\([0-9.]*\) ms/\2\t\1\t\3/' < lines.dat > parsed.dat

mkdir -p data_files

# create separate data files, one with the results from each trial
for i in {1..24}
do
	awk "/^$i\t/" < parsed.dat | sed "s/^$i\t\([A-Za-z0-9.-]*\)\t\([0-9.]*\)/\1\t\2/" >> data_files/d$i.dat
done

mkdir -p gp_scripts

# copy gnuplot template for each plot
for i in {1..24}
do
        sed "s/\*\*i\*\*/$i/" < plot_i.gp > gp_scripts/plot_$i.gp
done

mkdir -p pngs

# plot each set of data by executing each gnuplot script
for i in {1..24}
do
	gnuplot gp_scripts/plot_$i.gp
done

# execute ruby script for creating average data file
./average.rb

# copy gnuplot template for average plot
sed "s/\*\*i\*\*/AVG/" < plot_i.gp > gp_scripts/plot_AVG.gp
# plot the average set of data
gnuplot gp_scripts/plot_AVG.gp

# create report.tex, a latex file with all plots
echo '\documentclass{article}' > report.tex
echo '\usepackage{graphicx}' >> report.tex
echo '' >> report.tex
echo '\begin{document}' >> report.tex
echo '' >> report.tex

for i in {1..24}
do
	echo "\\includegraphics[width=\\textwidth]{pngs/plot_$i.png}" >> report.tex
done

echo "\\includegraphics[width=\\textwidth]{pngs/plot_AVG.png}" >> report.tex
echo '' >> report.tex
echo '\end{document}' >> report.tex

# compile latex file into pdf
pdflatex report

